@@ -1,7 +1,7 @@
 package Test::Perinci::CmdLine;
 
-our $DATE = '2016-08-03'; # DATE
-our $VERSION = '1.40'; # VERSION
+our $DATE = '2016-08-30'; # DATE
+our $VERSION = '1.41'; # VERSION
 
 use 5.010001;
 use strict;
@@ -356,6 +356,20 @@ sub square { my %args=@_; [200, "OK", $args{num}**2] }
                         exit_code   => 0,
                         stdout_like => qr/^Usage.+^([^\n]*)Options/ims,
                     },
+                    {
+                        name        => '+ is not accepted as option starter',
+                        gen_args    => {url => '/Perinci/Examples/Tiny/noop'},
+                        inline_gen_args => {load_module=>['Perinci::Examples::Tiny']},
+                        argv        => [qw/+h/],
+                        exit_code   => 200,
+                    },
+                    {
+                        name        => '+ is not accepted as option starter (2)',
+                        gen_args    => {url => '/Perinci/Examples/Tiny/noop'},
+                        inline_gen_args => {load_module=>['Perinci::Examples::Tiny']},
+                        argv        => [qw/+help/],
+                        exit_code   => 200,
+                    },
                     {
                         name        => 'extra args is okay',
                         gen_args    => {url => '/Perinci/Examples/Tiny/noop'},
@@ -1504,7 +1518,7 @@ Test::Perinci::CmdLine - Common test suite for Perinci::CmdLine::{Lite,Classic,I
 
 =head1 VERSION
 
-This document describes version 1.40 of Test::Perinci::CmdLine (from Perl distribution Test-Perinci-CmdLine), released on 2016-08-03.
+This document describes version 1.41 of Test::Perinci::CmdLine (from Perl distribution Test-Perinci-CmdLine), released on 2016-08-30.
 
 =head1 FUNCTIONS
 
